.. :changelog:

Release History
---------------

0.5 (2014-08-23)
++++++++++++++++
- Add %inline --format and --size options.


0.4 (2014-08-10)
++++++++++++++++
- Add Python 3 support.
- Add %inline plotting toggle.
- Add compatibility for oct2py >= 2.0.


0.3 (2014-08-03)
+++++++++++++++++
- Cache help strings and calltips for fast re-trigger.


0.2 (2014-08-02)
+++++++++++++++++
- Add history capability


0.1 (2014-08-01)
++++++++++++++++++
- Initial release: provides completion and calltips.
